@@ -1,10 +1,10 @@
 //use std::io::*;
 
-struct Circle {
+pub struct Circle {
   n: i32,
 }
 
-trait Info {
+pub trait Info {
   fn info_new(n: i32) -> Self;
   fn even_or_odd(&self) -> String;
 }
@@ -21,5 +21,5 @@ impl Info for Circle {
     }
   }
 }
-
+// use checkeo::*;
 fn main() {}
